import React, { Component } from 'react';
import styles from './style.css';
import { Radio, Toast, Button, TextareaItem } from 'antd-mobile';
import peopleIcon from './images/repair_people_icon@2x.png';
import phoneIcon from './images/phone_tel_icon@2x.png';
import roleIcon from './images/user_role_icon@2x.png';
import areaIcon from './images/repair_area_icon@2x.png';
import typeIcon from './images/repair_item_icon@2x.png';
import addrIcon from './images/repair_addr_icon@2x.png';
import imgIcon from './images/upload_pic_icon@2x.png';
import ImagePicker from '../../components/Input/ImagePicker/ImagePicker';
import Select from '../../components/Input/Select/Select';
import { fetchRepairArea, fetchRepairTerm } from '../../api/index';

class ReprtRepair extends Component {
  constructor(props) {
    super(props);
    this.state = {
      areaList: [],
      termList: [],
      applyForm: {
        name: '',
        userId: '',
        repairCellphone: '',
        applyIdentity: '学生',
        area: '',
        areaId: '',
        term: '',
        termId: '',
        address: '',
        uploadImg: [],
      },
    };
  }
  componentDidMount() {
    fetchRepairArea()
      .then(res => {
        this.setState(() => ({
          areaList: res.data,
        }));
      })
      .catch(err => {
        console.log(err);
      });
    fetchRepairTerm()
      .then(res => {
        this.setState(() => ({
          termList: res.data,
        }));
      })
      .catch(err => {
        console.log(err);
      });
  }

  onChangeHandle = e => {
    const { name, value } = e.target;
    this.setState(({ applyForm }) => ({
      applyForm: {
        ...applyForm,
        [name]: value,
      },
    }));
  };
  validateForm = () => {
    const { applyForm } = this.state;
    if (!applyForm.name) {
      Toast.fail('请输入报修人！');
      return;
    }
    if (!applyForm.repairCellphone) {
      Toast.fail('请输入报修人电话！');
      return;
    }
    if (!applyForm.applyIdentity) {
      Toast.fail('请选择报修人身份！');
      return;
    }
    if (!applyForm.areaId) {
      Toast.fail('请选择报修区域！');
      return;
    }
    if (!applyForm.termId) {
      Toast.fail('请选择报修项目！');
      return;
    }
    if (!applyForm.address) {
      Toast.fail('请输入报修地址！');
      return;
    }
    return true;
  };
  startApply = () => {
    if (!this.validateForm()) {
      return;
    }
  };
  render() {
    const { applyForm } = this.state;

    return (
      <div className={styles.wrap}>
        <div className={styles.listItem}>
          <i className={styles.itemIcon}>
            <img src={peopleIcon} alt="" />
          </i>
          <span className={styles.itemLabel}>报修人</span>
          <div className={styles.inputBox}>
            <input
              className={styles.input}
              type="text"
              maxLength="20"
              name="name"
              value={applyForm.name}
              onChange={this.onChangeHandle}
            />
          </div>
        </div>
        <div className={styles.listItem}>
          <i className={styles.itemIcon}>
            <img src={phoneIcon} alt="" />
          </i>
          <span className={styles.itemLabel}>报修人tel</span>
          <div className={styles.inputBox}>
            <input
              className={styles.input}
              type="tel"
              maxLength="11"
              name="repairCellphone"
              value={applyForm.repairCellphone}
              onChange={this.onChangeHandle}
            />
          </div>
        </div>
        <div className={styles.listItem}>
          <i className={styles.itemIcon}>
            <img src={roleIcon} alt="" />
          </i>
          <span className={styles.itemLabel}>报修身份</span>
          <div className={styles.inputBoxNoBB}>
            {/* <input className={styles.input} type="text" /> */}

            <Radio
              className="my-radio"
              name="applyIdentity"
              value="老师"
              checked={applyForm.applyIdentity === '老师'}
              onChange={this.onChangeHandle}
            >
              老师
            </Radio>
            <Radio
              className="my-radio"
              name="applyIdentity"
              value="学生"
              checked={applyForm.applyIdentity === '学生'}
              onChange={this.onChangeHandle}
            >
              学生
            </Radio>
          </div>
        </div>
        <div className={styles.listItem}>
          <i className={styles.itemIcon}>
            <img src={areaIcon} alt="" />
          </i>
          <span className={styles.itemLabel}>报修区域</span>
          <div className={styles.inputBox}>
            {/* <Picker data={areaList}>
              <List.Item arrow="horizontal" onClick={this.onClick} />
            </Picker> */}
            <Select placeholder="请选择" />
          </div>
        </div>
        <div className={styles.listItem}>
          <i className={styles.itemIcon}>
            <img src={typeIcon} alt="" />
          </i>
          <span className={styles.itemLabel}>报修项目</span>
          <div className={styles.inputBox}>
            <input className={styles.input} type="text" />
          </div>
        </div>
        <div className={styles.listItem}>
          <i className={styles.itemIcon}>
            <img src={addrIcon} alt="" />
          </i>
          <span className={styles.itemLabel}>报修地址</span>
        </div>
        <TextareaItem
          className="textarea"
          placeholder="输入报修地址"
          rows={3}
          count={50}
        />
        <div className={styles.listItem}>
          <i className={styles.itemIcon}>
            <img src={imgIcon} alt="" />
          </i>
          <span className={styles.itemLabel}>上传图片</span>
        </div>
        <div className={styles.imageArea}>
          <ImagePicker />
          <ImagePicker />
          <ImagePicker />
        </div>
        <Button className={styles.applyBtn} onClick={this.startApply}>
          提交
        </Button>
      </div>
    );
  }
}

export default ReprtRepair;
